@@ -51,12 +51,12 @@ void PagePainter::paintPageOnPainter( QPainter * destPainter, const Okular::Page
     int pixID, int flags, int scaledWidth, int scaledHeight, const QRect &limits )
 {
         paintCroppedPageOnPainter( destPainter, page, pixID, flags, scaledWidth, scaledHeight, limits,
-                                   Okular::NormalizedRect( 0, 0, 1, 1 ) );
+                                   Okular::NormalizedRect( 0, 0, 1, 1 ), 0 );
 }
 
 void PagePainter::paintCroppedPageOnPainter( QPainter * destPainter, const Okular::Page * page,
     int pixID, int flags, int scaledWidth, int scaledHeight, const QRect &limits,
-    const Okular::NormalizedRect &crop )
+    const Okular::NormalizedRect &crop, Okular::NormalizedPoint *viewPortPoint )
 {
 	/* Calculate the cropped geometry of the page */
 	QRect scaledCrop = crop.geometry( scaledWidth, scaledHeight );
@@ -209,7 +209,7 @@ void PagePainter::paintCroppedPageOnPainter( QPainter * destPainter, const Okula
 
     /** 3 - ENABLE BACKBUFFERING IF DIRECT IMAGE MANIPULATION IS NEEDED **/
     bool bufferAccessibility = (flags & Accessibility) && Okular::Settings::changeColors() && (Okular::Settings::renderMode() != Okular::Settings::EnumRenderMode::Paper);
-    bool useBackBuffer = bufferAccessibility || bufferedHighlights || bufferedAnnotations;
+    bool useBackBuffer = bufferAccessibility || bufferedHighlights || bufferedAnnotations || viewPortPoint;
     QPixmap * backPixmap = 0;
     QPainter * mixedPainter = 0;
     QRect limitsInPixmap = limits.translated( crop.geometry( scaledWidth, scaledHeight ).topLeft() );
@@ -239,6 +239,7 @@ void PagePainter::paintCroppedPageOnPainter( QPainter * destPainter, const Okula
     {
         // the image over which we are going to draw
         QImage backImage;
+        bool has_alpha = pixmap->hasAlpha();
 
         // 4B.1. draw the page pixmap: normal or scaled
         if ( pixmap->width() == scaledWidth && pixmap->height() == scaledHeight )
@@ -308,9 +309,26 @@ void PagePainter::paintCroppedPageOnPainter( QPainter * destPainter, const Okula
                     for( int x = highlightRect.left(); x <= highlightRect.right(); ++x )
                     {
                         val = data[ x + offset ];
-                        newR = (qRed(val) * rh) / 255;
-                        newG = (qGreen(val) * gh) / 255;
-                        newB = (qBlue(val) * bh) / 255;
+                        //for odt or epub
+                        if(has_alpha)
+                        {
+                            newR = qRed(val);
+                            newG = qGreen(val);
+                            newB = qBlue(val);
+
+                            if(newR == newG && newG == newB && newR == 0)
+                                newR = newG = newB = 255;
+
+                            newR = (newR * rh) / 255;
+                            newG = (newG * gh) / 255;
+                            newB = (newB * bh) / 255;
+                        }
+                        else
+                        {
+                            newR = (qRed(val) * rh) / 255;
+                            newG = (qGreen(val) * gh) / 255;
+                            newB = (qBlue(val) * bh) / 255;
+                        }
                         data[ x + offset ] = qRgba( newR, newG, newB, 255 );
                     }
                     offset += backImage.width();
@@ -506,6 +524,33 @@ void PagePainter::paintCroppedPageOnPainter( QPainter * destPainter, const Okula
             } // end current annotation drawing
         }
 
+        if(viewPortPoint)
+        {
+            QPainter painter(&backImage);
+            painter.translate( -limits.left(), -limits.top() );
+            painter.setPen( QApplication::palette().color( QPalette::Active, QPalette::Highlight ) );
+            painter.drawLine( 0, viewPortPoint->y * scaledHeight + 1, scaledWidth - 1, viewPortPoint->y * scaledHeight + 1 );
+// ROTATION CURRENTLY NOT IMPLEMENTED
+/*
+            if( page->rotation() == Okular::Rotation0)
+            {
+
+            }
+            else if(page->rotation() == Okular::Rotation270)
+            {
+                painter.drawLine( viewPortPoint->y * scaledHeight + 1, 0, viewPortPoint->y * scaledHeight + 1, scaledWidth - 1);
+            }
+            else if(page->rotation() == Okular::Rotation180)
+            {
+                painter.drawLine( 0, (1.0 - viewPortPoint->y) * scaledHeight - 1, scaledWidth - 1, (1.0 - viewPortPoint->y) * scaledHeight - 1 );
+            }
+            else if(page->rotation() == Okular::Rotation90) // not right, rotation clock-wise
+            {
+                painter.drawLine( scaledWidth - (viewPortPoint->y * scaledHeight + 1), 0, scaledWidth - (viewPortPoint->y * scaledHeight + 1), scaledWidth - 1);
+            }
+*/
+        }
+
         // 4B.5. create the back pixmap converting from the local image
         backPixmap = new QPixmap( QPixmap::fromImage( backImage ) );
 
